@@ -31,6 +31,8 @@
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
+#include <libmate-desktop/mate-aboutdialog.h>
+
 #include <gio/gio.h>
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
@@ -45,10 +47,6 @@
 #define APPLET_SCHEMA "org.mate.panel.applet.mate-window-picker-applet"
 #define SHOW_WIN_KEY "show-all-windows"
 
-#define MAXIMUS_SCHEMA "org.mate.maximus"
-#define UNDECORATE_KEY "undecorate"
-#define NO_MAXIMIZE_KEY "no-maximize"
-
 typedef struct 
 {
   GtkWidget    *tasks;
@@ -77,18 +75,18 @@ static void display_prefs_dialog (GtkAction    *action,
                                   WinPickerApp *applet);
 
 static const GtkActionEntry window_picker_menu_actions [] = {
-	{ "MenuPrefs", GTK_STOCK_PREFERENCES, N_("_Preferences"),
+  { "MenuPrefs", GTK_STOCK_PREFERENCES, N_("_Preferences"),
       NULL, NULL,
       G_CALLBACK (display_prefs_dialog) },
-	{ "MenuAbout", GTK_STOCK_ABOUT, N_("_About"),
+  { "MenuAbout", GTK_STOCK_ABOUT, N_("_About"),
       NULL, NULL,
       G_CALLBACK (display_about_dialog) }
 };
 
 static const gchar *close_window_authors [] = {
-	"Neil J. Patel <neil.patel@canonical.com>",
-    "Stefano Karapetsas <stefano@karapetsas.com>",
-	NULL
+  "Neil J. Patel <neil.patel@canonical.com>",
+  "Stefano Karapetsas <stefano@karapetsas.com>",
+  NULL
 };
 
 static void
@@ -131,13 +129,6 @@ force_no_focus_padding (GtkWidget *widget)
 static void
 cw_applet_finalize (GObject *object)
 {
-  /* disable Maximus */
-  GSettings *maximus_settings;
-  maximus_settings = g_settings_new (MAXIMUS_SCHEMA);
-  g_settings_set_boolean (maximus_settings, UNDECORATE_KEY, FALSE);
-  g_settings_set_boolean (maximus_settings, NO_MAXIMIZE_KEY, TRUE);
-  g_object_unref (maximus_settings);
-
   if (G_OBJECT_CLASS (parent_class)->finalize)
     (* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
@@ -155,7 +146,7 @@ cw_applet_fill (MatePanelApplet *applet,
   GObjectClass *object_class;
   
   if (strcmp (iid, "MateWindowPicker") != 0)
-		return FALSE;
+    return FALSE;
   	
   bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -167,18 +158,10 @@ cw_applet_fill (MatePanelApplet *applet,
   mainapp = app;
   screen = wnck_screen_get_default ();
 
-  /* prepare to disable Maximus */
   object_class = G_OBJECT_GET_CLASS (G_OBJECT(applet));
   object_class->finalize = cw_applet_finalize;
   parent_class = g_type_class_peek_parent (object_class);
 
-  /* enable Maximus */
-  GSettings *maximus_settings;
-  maximus_settings = g_settings_new (MAXIMUS_SCHEMA);
-  g_settings_set_boolean (maximus_settings, UNDECORATE_KEY, TRUE);
-  g_settings_set_boolean (maximus_settings, NO_MAXIMIZE_KEY, FALSE);
-  g_object_unref (maximus_settings);
-
   /* gsettings prefs */
   app->settings = mate_panel_applet_settings_new (applet, APPLET_SCHEMA);
   g_signal_connect (app->settings, "changed::" SHOW_WIN_KEY,
@@ -189,7 +172,7 @@ cw_applet_fill (MatePanelApplet *applet,
   gtk_container_set_border_width (GTK_CONTAINER (applet), 0);
 
   eb = gtk_hbox_new (FALSE, 6);
-	gtk_container_add (GTK_CONTAINER (applet), eb);
+  gtk_container_add (GTK_CONTAINER (applet), eb);
   gtk_container_set_border_width (GTK_CONTAINER (eb), 0);
 
   tasks = app->tasks = task_list_get_default ();
@@ -203,35 +186,34 @@ cw_applet_fill (MatePanelApplet *applet,
   on_show_all_windows_changed (app->settings, SHOW_WIN_KEY, app);
 		
   /* Signals */
-	g_signal_connect (applet, "change-background",
-			             G_CALLBACK (cw_panel_background_changed), NULL);
+  g_signal_connect (applet, "change-background",
+                    G_CALLBACK (cw_panel_background_changed), NULL);
 	
+  action_group = gtk_action_group_new ("MateWindowPicker Applet Actions");
+  gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+  gtk_action_group_add_actions (action_group,
+                                window_picker_menu_actions,
+                                G_N_ELEMENTS (window_picker_menu_actions),
+                                app);
+  ui_path = g_build_filename (MATEWINDOWPICKER_MENU_UI_DIR, "mate-window-picker-applet-menu.xml", NULL);
+  mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (app->applet),
+                                          ui_path, action_group);
+  g_free (ui_path);
+  g_object_unref (action_group);
 
-    action_group = gtk_action_group_new ("MateWindowPicker Applet Actions");
-    gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-    gtk_action_group_add_actions (action_group,
-                                  window_picker_menu_actions,
-                                  G_N_ELEMENTS (window_picker_menu_actions),
-                                  app);
-    ui_path = g_build_filename (MATEWINDOWPICKER_MENU_UI_DIR, "mate-window-picker-applet-menu.xml", NULL);
-    mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (app->applet),
-                                       ui_path, action_group);
-    g_free (ui_path);
-    g_object_unref (action_group);
-
-    mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), 
-                          MATE_PANEL_APPLET_EXPAND_MAJOR
-                            | MATE_PANEL_APPLET_EXPAND_MINOR
-                            | MATE_PANEL_APPLET_HAS_HANDLE);
+  mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), 
+                               MATE_PANEL_APPLET_EXPAND_MAJOR
+                               | MATE_PANEL_APPLET_EXPAND_MINOR
+                               | MATE_PANEL_APPLET_HAS_HANDLE);
 	
-	return TRUE;
+  return TRUE;
 }
 
 MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("MateWindowPickerFactory",
-                             PANEL_TYPE_APPLET,
-                             "MateWindowPicker",
-                             cw_applet_fill,
-                             NULL);
+                                       PANEL_TYPE_APPLET,
+                                       "MateWindowPicker",
+                                       cw_applet_fill,
+                                       NULL);
 
 static void 
 cw_panel_background_changed (MatePanelApplet               *applet,
@@ -296,7 +278,7 @@ display_about_dialog (GtkAction       *action,
 {
   GtkWidget *panel_about_dialog;
 	
-  panel_about_dialog = gtk_about_dialog_new ();
+  panel_about_dialog = mate_about_dialog_new ();
 
   g_object_set (panel_about_dialog,
                 "name", _("Window Picker"),
@@ -305,14 +287,13 @@ display_about_dialog (GtkAction       *action,
                 "authors", close_window_authors,
                 "logo-icon-name", "preferences-system-windows",
                 "copyright", "Copyright \xc2\xa9 2008 Canonical Ltd\n"
-                             "Copyright \xc2\xa9 2013 Stefano Karapetsas",
+                             "Copyright \xc2\xa9 2013-2014 Stefano Karapetsas",
                 NULL);
 
   gtk_widget_show (panel_about_dialog);
 
   g_signal_connect (panel_about_dialog, "response",
                     G_CALLBACK (gtk_widget_destroy), NULL);
-	
 
   gtk_window_present (GTK_WINDOW (panel_about_dialog));
 }
@@ -379,7 +360,7 @@ display_prefs_dialog (GtkAction       *action,
   g_signal_connect (window, "destroy",
                     G_CALLBACK (gtk_widget_destroy), window);
   g_signal_connect_swapped (button, "clicked",
-                    G_CALLBACK (gtk_widget_destroy), window);
+                            G_CALLBACK (gtk_widget_destroy), window);
 	
   gtk_window_present (GTK_WINDOW (window));
 }
